/******************************************************/
/* kilian.cmd, a script to copy and rename picture    */
/* files using EXIF data.                             */ 
/* Copyright (c) 2001,2002 by Dimitrios Bogiatzoules  */
/* info at bogiatzoules dot de                        */
/* This Program is released under the Gnu Public      */
/* Licence (GPL).                                     */
/* See the file COPYING for further information.      */
/*                                                    */
/*                                                    */
/* Please change the following 2 paths to your needs! */
/*                                                    */
/******************************************************/
/* Where should the renamed pictures be saved?        */
/* This directory must exist!!                        */
/******************************************************/
camera_dir='R:\data\camera'

/******************************************************/
/* Where is the renamepics.exe found?                 */
/******************************************************/
renamepics='D:\OPT\renamepics\renamepics.exe'

/******************************************************/
/* Do some basics ...                                 */
/******************************************************/
'@ECHO OFF'
CALL RxFuncAdd "SYSLoadFuncs","RexxUtil","SYSLoadFuncs"
CALL SYSLoadFuncs
version='0.1'

/******************************************************/
/* Set some colors, thanx to Dmitry A.Steklenev       */
/* enable ANSI extended screen and keyboard control   */
/******************************************************/
'@ansi on > nul'
color.brown   = "1B"x"[0;33m"
color.red     = "1B"x"[1;31m"
color.green   = "1B"x"[1;32m"
color.yellow  = "1B"x"[1;33m"
color.blue    = "1B"x"[1;34m"
color.magenta = "1B"x"[1;35m"
color.cyan    = "1B"x"[1;36m"
color.white   = "1B"x"[1;37m"
color.gray    = "1B"x"[0m"

/******************************************************/
/* Start message                                      */
/******************************************************/
SAY color.gray  || 'Thank you for using '|| color.magenta || 'Kilian' || color.gray || ', a tool to easily use renamepics.exe, ' || color.cyan || 'version 'version || color.gray || '.'
SAY color.gray || 'This Program is released under the Gnu Public Licence (GPL).'
SAY 'See the file COPYING for further information.'
SAY color.gray  || 'Copyright (c) 2003 by '|| color.white || 'Dimitrios Bogiatzoules'

/******************************************************/
/* save the current working directory                 */
/******************************************************/
cur_dir=DIRECTORY()

/******************************************************/
/* create a new directory to save the pics from       */
/* the camera (only if needed)                        */
/* Directrory format: YYYY_MM_DD                      */
/******************************************************/
td=DATE(S)
dotd=SUBSTR(td,1,4)'_'SUBSTR(td,5,2)'_'SUBSTR(td,7,2)

/******************************************************/
/* does this directory already exist?                 */
/******************************************************/
rc=SySFileTree(camera_dir'\'dotd,results,D)
IF rc=\"0" THEN
   DO
   SAY ' '
   SAY color.red || " ERROR: " || color.gray || 'Couldn''t access 'camera_dir'!'
   PAUSE
   EXIT 1 /* Exit with error */
   END

/******************************************************/
/* if not, create it!                                 */
/******************************************************/
IF results.0=0 THEN rc=SySMkDir(camera_dir'\'dotd)
IF rc=\"0" THEN
   DO
   SAY ' '
   SAY color.red || " ERROR: " || color.gray || 'Couldn''t create 'camera_dir'\'dotd'!'
   PAUSE
   EXIT 1 /* Exit with error */
   END

/******************************************************/
/* get the image directory (on the camera?)           */
/******************************************************/
PARSE ARG dir_with_files2rename             

IF dir_with_files2rename="" THEN
   DO
   SAY ' '
   SAY color.red || " ERROR: " || color.gray || 'Please drop the directory which contains the image files to rename!'
   PAUSE
   EXIT 1 /* Exit with error */
   END

/******************************************************/
/* put the picture files in a list                    */
/******************************************************/
rc=SysFileTree(dir_with_files2rename'\*.jpg',pictures,O)

/******************************************************/
/* now copy the picture files                         */
/******************************************************/
DO i=1 to pictures.0
  COPY pictures.i camera_dir'\'dotd '2>nul >nul'
END

/******************************************************/
/* .. then change the working dir ...                 */
/******************************************************/
CALL DIRECTORY camera_dir'\'dotd

/******************************************************/
/* ...rename the files using EXIF info...             */
/******************************************************/
DO i=1 to pictures.0
  f2r=FILESPEC("name",pictures.i) /* extraxt the filename only! */
  renamepics camera_dir'\'dotd'\'f2r ' >nul'
END

/******************************************************/
/* ... and finally return home ;-)                    */
/******************************************************/
CALL DIRECTORY cur_dir
call beep 1000,50
SAY ' '
SAY color.red || "Done!" || color.gray || ' But please look at the saved files before deleting then on the camera!'
PAUSE
EXIT
